#!/usr/bin/env python3

'''Functions for generating ShadowHashData'''

import hashlib
import os
import plistlib

import arc4random
import pbkdf2


def make_salt(saltlen):
    '''Generate a random salt'''
    salt = bytes(arc4random.randsample(0, 255, saltlen))
    return salt


def generate(password):
    '''Generate a ShadowHashData structure as used by macOS 10.8+'''
    iterations = arc4random.randrange(30000, 50000)
    salt = make_salt(32)
    keylen = 128

    password = password.encode('utf-8')

    entropy = hashlib.pbkdf2_hmac(
        'sha512', password, salt, iterations, dklen=keylen)

    data = {'SALTED-SHA512-PBKDF2': {'entropy': entropy,
                                     'iterations': iterations,
                                     'salt': salt},
            }

    return plistlib.dumps(data, fmt=plistlib.FMT_BINARY)